// pages/mine/mine.js
import UserApi from '../../../net/api/userApi'
import {
    copyrightUrl
} from '../../../net/http'
const Utils = require('../../../utils/util')
const app = getApp()
const deviceInfo = wx.getDeviceInfo()
const screenInfo = wx.getWindowInfo();
const statusBarHeight = screenInfo.statusBarHeight; // 状态栏高度
const navBarHeight = deviceInfo.platform == 'IOS' ? 48 : 50; // 导航栏高度（iOS 为 44px，Android 为 48px）
const windowHeight = screenInfo.windowHeight - navBarHeight - statusBarHeight; //可用内容高度
Page({

    /**
     * 页面的初始数据
     */
    data: {
        statusBarHeight: statusBarHeight,
        navBarHeight: navBarHeight,
        totalHeight: navBarHeight, // 导航栏总高度
        contentHeight: windowHeight,
        allCount: 0,
        materialCount: 0,
        accountInfo: {},
        menuList: [{
            "icon": "ic-user",
            "title": "个人信息",
            "path": "/pages/mine/mineAccount/mineInfo/mineInfo"
        }, {
            "icon": "ic-order",
            "title": "我的订单",
            "path": "/pages/mine/mineAccount/mineOrder/mineOrder"
        }, {
            "icon": "ic-invoice",
            "title": "发票管理",
            "path": ""
        }, {
            "icon": "ic-contact",
            "title": "产权联系人",
            "path": "/pages/mine/mineAccount/mineContact/mineContact"
        }],
        buttons: [{
            text: '知道了'
        }],
        hintTxt: '',
        showHint: false
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
        const _self = this
        _self.getMineAccount()
        _self.getMinePackageCount()
        const h = Utils.pxToRpx(_self.data.contentHeight)
        _self.setData({
            contentHeight: h
        })
    },
    onShow(options) {
        this.getMineAccount() //获取账户信息
        this.getMinePackageCount() //获取套餐包信息
    },
    getMineAccount() {
        const _self = this
        UserApi.doGetMineAccount()
            .then(res => {
                _self.setData({
                    accountInfo: res
                })
            }, err => {
                console.log(err)
            })
    },
    getMinePackageCount() {
        const _self = this
        UserApi.doGetMinePackageCount()
            .then(res => {
                console.log(res)
                _self.setData({
                    allCount: res.ALL,
                    materialCount: res.MATERIAL
                })
            }, err => {
                console.log(err)
                _self.setData({
                    allCount: 0,
                    materialCount: 0
                })
            })
    },
    //优惠卷
    doCoupons() {
        wx.navigateTo({
            url: '/pages/mine/mineAccount/mineCoupons/mineCoupons',
        })
    },
    //跳转充值页面
    doPay() {
        wx.navigateTo({
            url: '/pages/copyright/payment/payment',
        })
    },
    //条目点击
    itemClick(e) {
        const path = e.currentTarget.dataset.path
        if (path == '') {
            this.setData({
                showHint: true,
                hintTxt: `鉴于功能特性，需在电脑端完成操作。请打开浏览器，登录网址${copyrightUrl}，进行后续操作。`
            })
        } else {
            wx.navigateTo({
                url: path,
            })
        }
    },
    closeHint(e) {
        this.setData({
            showHint: false,
            hintTxt: ''
        })
    }
})